@@ -98,20 +98,20 @@ where
     /// Execute a contract and process all returned messages.
     /// This is just a helper around execute(),
     /// but we parse out the data field to that what is returned by the contract (not the protobuf wrapper)
-    fn execute_contract<T: Serialize>(
+    fn execute_contract<T: Serialize + std::fmt::Debug>(
         &mut self,
         sender: Addr,
         contract_addr: Addr,
         msg: &T,
         send_funds: &[Coin],
     ) -> AnyResult<AppResponse> {
-        let msg = to_binary(msg)?;
-        let msg = WasmMsg::Execute {
-            contract_addr: contract_addr.into(),
-            msg,
+        let binary_msg = to_binary(msg)?;
+        let wrapped_msg = WasmMsg::Execute {
+            contract_addr: contract_addr.into_string(),
+            msg: binary_msg,
             funds: send_funds.to_vec(),
         };
-        let mut res = self.execute(sender, msg.into())?;
+        let mut res = self.execute(sender, wrapped_msg.into())?;
         res.data = res
             .data
             .and_then(|d| parse_execute_response_data(d.as_slice()).unwrap().data);
